@@ -10,8 +10,8 @@ def test_im2dhist_with_param():
 
     # 2*w_neighboring+1 is width of the square window around each pixel, when counting neiboring pixels
     # calculate 2 dimensional histogram of gray_image
-    v_image_2DHisteq = im2dhist(gray_image, w_neighboring=6, showProgress = True)
+    v_image_2DHisteq = im2dhist(gray_image, w_neighboring=6)
     # np.save(f'{image_name}-2D-Histogram', v_image_2DHisteq)
     v_image_2DHisteq_cmpr = np.load(f'{image_name}-2D-Histogram.npy')
     assert np.all(v_image_2DHisteq == v_image_2DHisteq_cmpr)
-    
\ No newline at end of file
+    
